pub fn serialize_le(
record: &LasPointRecord,
layout: &StreamingLayout,
dst: &mut [u8],
)Expand description
Serialize one record into dst using the fixed little-endian spill format.
pub fn serialize_le(
record: &LasPointRecord,
layout: &StreamingLayout,
dst: &mut [u8],
)Serialize one record into dst using the fixed little-endian spill format.