pub struct ColumnSpec {
pub dimension: LasDimension,
pub scalar: ScalarType,
pub byte_width: Option<usize>,
}Expand description
Declares the LAS/COPC dimension and scalar type for a column.
Fields
dimension: LasDimensionscalar: ScalarTypebyte_width: Option<usize>For LasDimension::ExtraBytes, the fixed byte count stored for each point.
Implementations
Sourceimpl ColumnSpec
impl ColumnSpec
pub const fn new(dimension: LasDimension, scalar: ScalarType) -> Self
pub const fn extra_bytes(byte_width: usize) -> Self
Sourcepub const fn default_for(dimension: LasDimension) -> Option<Self>
pub const fn default_for(dimension: LasDimension) -> Option<Self>
Returns the default fixed LAS/COPC scalar for dimension, when it has one.
Sourcepub const fn has_default_scalar(self) -> bool
pub const fn has_default_scalar(self) -> bool
Returns whether this specification has the canonical scalar for its dimension.
Sourcepub const fn matches_data(self, data: &ColumnData) -> bool
pub const fn matches_data(self, data: &ColumnData) -> bool
Returns whether data has the scalar type declared by this spec.
Sourcepub fn validate_data(self, data: &ColumnData) -> Result<()>
pub fn validate_data(self, data: &ColumnData) -> Result<()>
Validate the declared scalar against the supplied data.
Sourcepub fn validate_default_scalar(self) -> Result<()>
pub fn validate_default_scalar(self) -> Result<()>
Validate that this spec uses the fixed LAS/COPC scalar for its dimension.
pub fn extra_byte_width(self) -> Option<usize>
pub fn point_count_for_data(self, data: &ColumnData) -> Result<usize>