Module streaming

Module streaming 

Streaming LAS point record plus explicit little-endian spill bytes.

Structs

LasPointRecord
In-memory representation of one full-fidelity LAS point.
StreamingLayout
Records which optional dimensions are present in a streaming pass.

Functions

deserialize_le
Deserialize one record from the little-endian spill bytes.
serialize_le
Serialize one record into dst using the fixed little-endian spill format.